package cn.minbb.serial.activities;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import java.io.File;
import java.nio.charset.Charset;

import cn.minbb.serial.R;
import cn.minbb.serialport.SerialPortManager;
import cn.minbb.serialport.listener.OnOpenSerialPortListener;
import cn.minbb.serialport.listener.OnSerialPortDataListener;
import cn.minbb.serialport.utils.ByteUtil;

public class MainActivity extends AppCompatActivity {

    private String TAG = "MainActivity";
    private Button openSerial, closeSerial;
    private EditText editText;
    private TextView textView;
    private SerialPortManager serialPortManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        openSerial = findViewById(R.id.open_serial_port);
        closeSerial = findViewById(R.id.close_serial_port);
        closeSerial.setEnabled(false);
        editText = findViewById(R.id.edit_text);
        textView = findViewById(R.id.text_view);

        serialPortManager = new SerialPortManager();
        serialPortManager.setOnOpenSerialPortListener(new OnOpenSerialPortListener() {
            @Override
            public void onSuccess(File device) {
                Toast.makeText(getApplicationContext(), "串口打开成功", Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onFail(File device, Status status) {
                Toast.makeText(getApplicationContext(), "串口打开失败", Toast.LENGTH_SHORT).show();
            }
        });
        serialPortManager.setOnSerialPortDataListener(new OnSerialPortDataListener() {
            @Override
            public void onDataReceived(byte[] bytes, String data) {
                runOnUiThread(() -> {
                    byte[] bytes1 = ByteUtil.addBytes(data.getBytes(), new byte[64]);
                    setText(data, data.length());
                    try {
                        if (serialPortManager.sendBytes(bytes1)) {
                            Toast.makeText(getApplicationContext(), "发送成功 = " + data, Toast.LENGTH_SHORT).show();
                        } else {
                            Toast.makeText(getApplicationContext(), "发送失败", Toast.LENGTH_SHORT).show();
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                        Toast.makeText(getApplicationContext(), "发送失败 " + e.getMessage(), Toast.LENGTH_SHORT).show();
                    }
                });
            }

            @Override
            public void onDataSent(byte[] bytes) {
            }
        });
    }

    private void setText(String data, int size) {
        String string = "data = " + data + ": " + size + "\n" + textView.getText();
        textView.setText(string);
    }

    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.open_serial_port:
                if (serialPortManager.openDefaultSerialPort()) {
                    Toast.makeText(getApplicationContext(), "串口打开成功", Toast.LENGTH_SHORT).show();
                    openSerial.setEnabled(false);
                    closeSerial.setEnabled(true);
                } else {
                    Toast.makeText(getApplicationContext(), "串口打开失败", Toast.LENGTH_SHORT).show();
                }
                break;
            case R.id.close_serial_port:
                Toast.makeText(getApplicationContext(), "串口已关闭", Toast.LENGTH_SHORT).show();
                serialPortManager.closeSerialPort();
                openSerial.setEnabled(true);
                closeSerial.setEnabled(false);
                break;
            case R.id.send:
                // byte[] reportID = {0x0};
                // byte[] data = ByteUtil.addBytes(reportID, editText.getText().toString().getBytes());
                boolean sendBytes = false;
                try {
                    sendBytes = serialPortManager.sendString(editText.getText().toString());
                    if (sendBytes) {
                        Toast.makeText(getApplicationContext(), "数据发送成功", Toast.LENGTH_SHORT).show();
                    } else {
                        Toast.makeText(getApplicationContext(), "数据发送失败", Toast.LENGTH_SHORT).show();
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    Toast.makeText(getApplicationContext(), "数据发送失败 " + e.getMessage(), Toast.LENGTH_SHORT).show();
                }
                break;
            case R.id.clearSend:
                editText.setText("");
                break;
            case R.id.clearText:
                textView.setText("");
                break;
        }
    }
}
